<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Casual</title>
  <link href="{{ url_for('static', filename='casual.css') }}" rel="stylesheet">
</head>

<body>
  <h1>Casual</h1>
</body>

</html>